//
// KickerHuhn - a little bit of action for your desktop's edge
// Copyright (C) 2001, 2002 Josef Spillner, dr_maux@users.sourceforge.net
// Published under GNU GPL conditions
//

#include "canvas.h"
#include "huhn.h"
#include "missile.h"

#include <kstandarddirs.h>
#include <krandomsequence.h>

Canvas::Canvas(QObject *parent, const char *name)
: QCanvas(parent, name)
{
	KStandardDirs d;
	QCanvasPixmapArray *a;

	m_score = 0;

	delay = 50; // start with medium difficulty level

	QString pixmap(d.findResource("data", "kickerhuhn/crosshair.png"));
	a = new QCanvasPixmapArray(pixmap);
	if(a->image(0)) a->image(0)->setOffset(16, 16);
	cross = new QCanvasSprite(a, this);
	cross->move(10, 10);
	cross->setZ(2.0);
	cross->show();

	create();
	create();

	txt = new QCanvasText(this);
	txt->setFont(QFont("arial", 8, QFont::Black));
	txt->setColor(QColor(0, 0, 100));
	txt->setText("Go huhn!");
	txt->move(70, 1);
	txt->setZ(1.0);
	txt->show();

	startTimer(50);
	setAdvancePeriod(1);

	slotBackground("landscape");

	resize(120, 40); // !!! FIX THIS DUDE !!!
}

Canvas::~Canvas()
{
}

void Canvas::create()
{
	QCanvasPixmapArray *a;
	Huhn *huhn;
	KRandomSequence rand;
	KStandardDirs d;

	a = new QCanvasPixmapArray();
	a->readPixmaps(d.findResource("data", "kickerhuhn/huhn0000.png")); // the trolls fixed the bug in qt :)
	a->setImage(1, new QCanvasPixmap(d.findResource("data", "kickerhuhn/huhn0001.png")));
	huhn = new Huhn(a, this);
	huhn->move(rand.getLong(120), 1 - rand.getLong(20));
	huhn->show();
	huhnlist.append(huhn);
}

void Canvas::slotMouse(int x, int y, int fire)
{
	if(fire)
	{
		Missile *m = new Missile(x, y);
		m->launch(); // preparation... it will have been a huhn for the longest time
		missiles.append(m);
	}
	else
	{
		cross->move(x, y);

		for(Huhn *huhn = huhnlist.first(); huhn; huhn = huhnlist.next())
		{
			if((x > huhn->x()) && (y > huhn->y()) && (x < huhn->x() + 16) && (y < huhn->y() + 16))
			{
				if(huhn->speed()) huhn->setSpeed(-4); // turbohuhn only when alive
				return;
			}
		}
	}
}

void Canvas::timerEvent(QTimerEvent *e)
{
	double x, y;
	KRandomSequence rand;

	for(Huhn *huhn = huhnlist.first(); huhn; huhn = huhnlist.next())
	{
		if(!huhn->timeToLive())
		{
			huhnlist.remove(huhn);
			delete huhn;
			continue;
		}
		x = huhn->x();
		y = huhn->y();
		y += huhn->speed();
		if((y > 40) || (y < -40))
		{
			if(y > 40.0) txt->setText(QString("Score: %1").arg(--m_score));
			y = (-(double)(rand.getLong(20)) - (double)16.0); // gcc sucks without .0
			x = rand.getLong(120);
			huhn->setSpeed(rand.getLong(2) + 1);
			huhn->setFrame(0);
		}
		huhn->move(x, y);
	}

	for(Missile *m = missiles.first(); m; m = missiles.next())
	{
		if(m->hit())
		{
			for(Huhn *huhn = huhnlist.first(); huhn; huhn = huhnlist.next())
			{
				if((m->x() > huhn->x()) && (m->y() > huhn->y()) && (m->x() < huhn->x() + 16) && (m->y() < huhn->y() + 16))
				{
					huhn->setSpeed(0); // tja, das war's wohl fr's huhn.
					huhn->setFrame(1);
					m_score += 2;
					txt->setText(QString("Score: %1").arg(m_score));
					if(!rand.getLong(delay / 10)) create(); // let's not be too nasty (level: havoc)
				}
			}
			missiles.remove(m);
			delete m;
		}
	}

	if(!rand.getLong(delay)) create(); // geflgel flooding :)
}

void Canvas::slotLevel(int level)
{
	delay = level;
}

void Canvas::slotBackground(QString background)
{
	KStandardDirs d;
	setBackgroundPixmap(d.findResource("data", QString("kickerhuhn/%1.png").arg(background)));
}

