//
// KickerHuhn - a little bit of action for your desktop's edge
// Copyright (C) 2001, 2002 Josef Spillner, dr_maux@users.sourceforge.net
// Published under GNU GPL conditions
//

#include "game.h"

#include <klocale.h>
#include <kaboutapplication.h>

#include <qpopupmenu.h>

Game::Game(QCanvas *canvas, QWidget *parent, const char *name)
: QCanvasView(canvas, parent, name)
{
	menu = new QPopupMenu(this);

	QPopupMenu *submenu_bg = new QPopupMenu(menu);
	QPopupMenu *submenu_level = new QPopupMenu(menu);

	submenu_bg->insertItem(i18n("Forest"), bg_forest);
	submenu_bg->insertItem(i18n("Desert"), bg_desert);
	submenu_level->insertItem(i18n("Easy"), level_easy);
	submenu_level->insertItem(i18n("Medium"), level_medium);
	submenu_level->insertItem(i18n("Hard"), level_hard);

	menu->insertItem(i18n("Background"), submenu_bg);
	menu->insertItem(i18n("Level"), submenu_level);
	menu->insertItem(i18n("About..."), about_about);

	connect(menu, SIGNAL(activated(int)), SLOT(slotActivated(int)));
	connect(submenu_bg, SIGNAL(activated(int)), SLOT(slotActivated(int)));
	connect(submenu_level, SIGNAL(activated(int)), SLOT(slotActivated(int)));

	setMouseTracking(1);
}

Game::~Game()
{
}

void Game::mouseMoveEvent(QMouseEvent *e)
{
	emit signalMouse(e->x(), e->y(), 0);
}

void Game::contentsMousePressEvent(QMouseEvent *e)
{
	if(e->button() == RightButton)
	{
		menu->popup(e->globalPos());
	}
	else emit signalMouse(e->x(), e->y(), 1);
}

void Game::slotActivated(int id)
{
	switch(id)
	{
		case about_about:
			about();
		case level_easy:
			emit signalLevel(100);
			break;
		case level_medium:
			emit signalLevel(50);
			break;
		case level_hard:
			emit signalLevel(10);
			break;
		case bg_forest:
			emit signalBackground("landscape");
			break;
		case bg_desert:
			emit signalBackground("desert");
			break;
		default:
			break;
	}
}

void Game::about()
{
	KAboutData aboutdata("kickerhuhn",
		"KickerHuhn",
		"0.2",
		I18N_NOOP("A small action game"),
		KAboutData::License_GPL,
		"Copyright (C) 2001, 2002 Josef Spillner",
		NULL,
		"http://games.kde.org",
		"dr_maux@users.sourceforge.net");
	aboutdata.addAuthor("Josef Spillner", I18N_NOOP("Development"), "dr_maux@users.sourceforge.net");

	KAboutApplication aboutdialog(&aboutdata, this);
	aboutdialog.exec();
}

